@@ -44,7 +44,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 179
+#define gmic_version 202
 
 #include <cstdio>
 #include <cstring>
@@ -137,6 +137,12 @@ namespace cimg_library {
 
 #else // #ifndef gmic_build
 
+#ifdef __GNUC__
+#if defined(__FAST_MATH__)
+#error Using the -ffast-math CFLAG is known to lead to important issues in libgmic. Please disable it to compile.
+#endif
+#endif
+
 // Define private functions, used to compile libgmic.
 //---------------------------------------------------
 
@@ -240,9 +246,9 @@ struct gmic {
              const char *const custom_commands, const bool include_stdlib,
              float *const p_progress, bool *const p_is_abort);
 
-  inline const char * set_variable(const char *const name, const char *const value,
-                                   const char operation='=',
-                                   const unsigned int *const variables_sizes=0);
+  const char *set_variable(const char *const name, const char *const value,
+                           const char operation='=',
+                           const unsigned int *const variables_sizes=0);
 
   gmic& add_commands(const char *const data_commands, const char *const commands_file=0);
   gmic& add_commands(std::FILE *const file, const char *const filename=0);
@@ -349,14 +355,14 @@ struct gmic {
   gmic_list<char> *const commands, *const commands_names, *const commands_has_arguments,
     *const _variables, *const _variables_names, **const variables, **const variables_names,
     commands_files, callstack;
-  gmic_list<unsigned int> dowhiles, repeatdones;
+  gmic_image<unsigned int> dowhiles, fordones, repeatdones;
   gmic_image<unsigned char> light3d;
   gmic_image<char> status;
   void *display_window;
 
   float focale3d, light3d_x, light3d_y, light3d_z, specular_lightness3d, specular_shininess3d, _progress, *progress;
   unsigned long reference_time;
-  unsigned int nb_carriages, debug_filename, debug_line, cimg_exception_mode;
+  unsigned int nb_dowhiles, nb_fordones, nb_repeatdones, nb_carriages, debug_filename, debug_line, cimg_exception_mode;
   int verbosity, render3d, renderd3d;
   bool is_released, is_debug, is_running, is_start, is_return, is_quit, is_double3d, is_debug_info, check_elif;
   const char *starting_commands_line;
